@@ -188,21 +188,21 @@ tcpproxy.pl - Simple TCP proxy for debugging connections
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
   $ tcpproxy.pl 2300 localhost 23
   starting proxy on 127.0.0.1:2300
-  received connection from 127.0.0.1:37941
-   IN [fffd[CAN]fffd fffd#fffd']
-  OUT [fffb[CAN]fffb fffb#fffb']
-   IN [fffa [NUL]fff0fffa#[NUL]fff0fffa'[NUL]fff0fffa[CAN][NUL]fff0]
-  OUT [fffa 0038400,38400fff0fffa#00localhost:16.0fff0fffa'0000DISPLAY[NUL]localhost:16.0fff0fffa[CAN]00xtermfff0]
-   IN [fffb[STX]fffd[NUL]fffd[US]fffb[ENQ]fffd!]
-  OUT [fffd[STX]fffc[NUL]fffb[US]fffa[US]00c00vfff0fffd[ENQ]fffb!]
-   IN [fffb[NUL]]
-  OUT [fffd[NUL]]
+  received connection from 127.0.0.1:37978
+   IN [<ff><fd>[CAN]<ff><fd> <ff><fd>#<ff><fd>']
+  OUT [<ff><fb>[CAN]<ff><fb> <ff><fb>#<ff><fb>']
+   IN [<ff><fa> [NUL]<ff><f0><ff><fa>#[NUL]<ff><f0><ff><fa>'[NUL]<ff><f0><ff><fa>[CAN][NUL]<ff><f0>]
+  OUT [<ff><fa> <00>38400,38400<ff><f0><ff><fa>#<00>localhost:16.0<ff><f0><ff><fa>'<00><00>DISPLAY[NUL]localhost:16.0<ff><f0><ff><fa>[CAN]<00>xterm<ff><f0>]
+   IN [<ff><fb>[STX]<ff><fd>[NUL]<ff><fd>[US]<ff><fb>[ENQ]<ff><fd>!]
+  OUT [<ff><fd>[STX]<ff><fc>[NUL]<ff><fb>[US]<ff><fa>[US]<00>c<00>v<ff><f0><ff><fd>[ENQ]<ff><fb>!]
+   IN [<ff><fb>[NUL]]
+  OUT [<ff><fd>[NUL]]
    IN [Debian GNU/Linux 7[CR][LF]]
    IN [bigbird login: ]
   OUT [a]
@@ -211,16 +211,21 @@ version 0.002
    IN [t]
   OUT [c]
    IN [c]
-  OUT [[CR]00]
+  OUT [[CR]<00>]
    IN [[CR][LF]]
    IN [Password: ]
   OUT [a]
   OUT [t]
   OUT [c]
-  OUT [[CR]00]
+  OUT [a]
+  OUT [t]
+  OUT [c]
+  OUT [a]
+  OUT [t]
+  OUT [c]
+  OUT [[CR]<00>]
    IN [[CR][LF]]
-   IN [Last login: Fri Dec  5 01:49:52 CET 2014 from localhost on pts/7[CR][LF]Linux bigbird 3.2.0-4-amd64 #1 SMP Debian 3.2.63-2+deb7u1 x86_64[CR][LF][CR][LF]The programs included with the Debian GNU/Linux system are free software;[CR][LF]the exact distribution terms for each program are described in the[CR][LF]individual files in /usr/share/doc/*/copyright.[CR][LF]]
-   IN [[CR][LF]Debian GNU/Linux comes with ABSOLUTELY NO WARRANTY, to the extent[CR][LF]permitted by applicable law.[CR][LF]]
+   IN [Last login: Fri Dec  5 01:58:51 CET 2014 from localhost on pts/7[CR][LF]Linux bigbird 3.2.0-4-amd64 #1 SMP Debian 3.2.63-2+deb7u1 x86_64[CR][LF][CR][LF]The programs included with the Debian GNU/Linux system are free software;[CR][LF]the exact distribution terms for each program are described in the[CR][LF]individual files in /usr/share/doc/*/copyright.[CR][LF][CR][LF]Debian GNU/Linux comes with ABSOLUTELY NO WARRANTY, to the extent[CR][LF]permitted by applicable law.[CR][LF]]
    IN [[ESC]]0;atc@bigbird: ~[BEL]atc@bigbird:~$ ]
   OUT [[ETX]]
    IN [logout[CR][LF]]
